/* machine.c for QNX 4 */

/****************
Date and time functions are standard UNIX-style functions.  "nixtime.i"
will be included by machine.c.
*/

#include <sys/types.h>
#include <sys/stat.h>
#include <time.h>
#include <utime.h>

/* Function isadir() returns 1 if the supplied handle is a directory, 
else it returns 0.  
*/

int isadir (file)
ZOOFILE file;
{
   int handle = fileno(file);
   struct stat buf;           /* buffer to hold file information */
   if (fstat (handle, &buf) == -1) {
      return (0);             /* inaccessible -- assume not dir */
   } else {
      if (buf.st_mode & S_IFDIR)
         return (1);
      else
         return (0);
   }
}

/****************
Function fixfname() converts the supplied filename to a syntax
legal for the host system.  It is used during extraction.
*/

char *fixfname(fname)
char *fname;
{
   return (fname); /* default is no-op */
}

/*****************
Function mktemp() accepts a template of the form `baseXXXXXX' where
base is an arbitrary string, and returns a unique temporary filename.
If template is not correct, it is returned unchanged.
*/
char *mktemp(template)
char *template;
{
#ifndef NDEBUG
   if (instr(template, "XXXXXX") == -1)
      prterror ('w', "Incorrect template [%s] supplied to mktemp().\n",
         template);
#endif

   strcpy(&template[instr(template, "XXXXXX")],"z.@@@");
   return (template);
}

/* Function gettz(), returns the offset from GMT in seconds of the
local time, taking into account daylight savings time */
long gettz()
{
	struct tm *tm;
	time_t sysclock;

	sysclock = time ((time_t *) 0);
	tm = localtime (&sysclock);
   return (timezone - tm->tm_isdst*3600);
}

/* Standard UNIX-compatible time functions */
#include "nixtime.i"

/* Standard UNIX-specific file attribute routines */
#include "nixmode.i"
